@@ -755,7 +755,7 @@ int main( int argc, char *argv[] )
     if( argc - optind != 1 )
     {
     usage:
-        printf( usage, _VER_MAJOR, _VER_MINOR );
+        printf( usage, _MAJ, _MIN );
         return( 1 );
     }
 
@@ -804,7 +804,8 @@ int main( int argc, char *argv[] )
         SWAP32( pfh.linktype );
 
     if( pfh.linktype != LINKTYPE_IEEE802_11 &&
-        pfh.linktype != LINKTYPE_PRISM_HEADER )
+        pfh.linktype != LINKTYPE_PRISM_HEADER &&
+        pfh.linktype != LINKTYPE_RADIOTAP_HDR )
     {
         printf( "\"%s\" isn't a regular 802.11 "
                 "(wireless) capture.\n", argv[optind] );
@@ -926,6 +927,18 @@ int main( int argc, char *argv[] )
             h80211 += n; pkh.caplen -= n;
         }
 
+        if( linktype == LINKTYPE_RADIOTAP_HDR )
+        {
+            /* remove the radiotap header */
+
+            n = *(unsigned short *)( h80211 + 2 );
+
+            if( n <= 0 || n >= (int) pkh.caplen )
+                continue;
+
+            h80211 += n; pkh.caplen -= n;
+        }
+
         /* remove the FCS if present (madwifi) */
 
         if( check_crc_buf( h80211, pkh.caplen - 4 ) == 1 )
